@@ -3,7 +3,6 @@ package output
 import (
 	"bytes"
 	"io"
-	"io/ioutil"
 	"os"
 	"path"
 	"testing"
@@ -36,7 +35,7 @@ func TestPlan_Write(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			tempDir := t.TempDir()
-			tempFile, err := ioutil.TempFile(tempDir, "result")
+			tempFile, err := os.CreateTemp(tempDir, "result")
 			if err != nil {
 				t.Fatal(err)
 			}
@@ -44,17 +43,17 @@ func TestPlan_Write(t *testing.T) {
 			if err := c.Write(tt.analysis); (err != nil) != tt.wantErr {
 				t.Errorf("Write() error = %v, wantErr %v", err, tt.wantErr)
 			}
-			result, err := ioutil.ReadFile(tempFile.Name())
+			result, err := os.ReadFile(tempFile.Name())
 			if err != nil {
 				t.Fatal(err)
 			}
 			expectedFilePath := path.Join("./testdata/", tt.goldenfile)
 			if *goldenfile.Update == tt.goldenfile {
-				if err := ioutil.WriteFile(expectedFilePath, result, 0600); err != nil {
+				if err := os.WriteFile(expectedFilePath, result, 0600); err != nil {
 					t.Fatal(err)
 				}
 			}
-			expected, err := ioutil.ReadFile(expectedFilePath)
+			expected, err := os.ReadFile(expectedFilePath)
 			if err != nil {
 				t.Fatal(err)
 			}
@@ -113,11 +112,11 @@ func TestPlan_Write_stdout(t *testing.T) {
 
 			expectedFilePath := path.Join("./testdata/", tt.goldenfile)
 			if *goldenfile.Update == tt.goldenfile {
-				if err := ioutil.WriteFile(expectedFilePath, result, 0600); err != nil {
+				if err := os.WriteFile(expectedFilePath, result, 0600); err != nil {
 					t.Fatal(err)
 				}
 			}
-			expected, err := ioutil.ReadFile(expectedFilePath)
+			expected, err := os.ReadFile(expectedFilePath)
 			if err != nil {
 				t.Fatal(err)
 			}
