@@ -4,7 +4,7 @@ import (
 	"errors"
 
 	"github.com/jmespath/go-jmespath"
-	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/enumeration/resource"
 )
 
 type FilterEngine struct {
