@@ -5,8 +5,8 @@ import (
 
 	"github.com/aws/aws-sdk-go/service/cloudfront"
 
+	awsresources "github.com/snyk/driftctl/enumeration/resource/aws"
 	"github.com/snyk/driftctl/pkg/analyser"
-	awsresources "github.com/snyk/driftctl/pkg/resource/aws"
 	"github.com/snyk/driftctl/test"
 
 	"github.com/r3labs/diff/v2"
