@@ -2,11 +2,13 @@ package aws
 
 import (
 	"github.com/snyk/driftctl/enumeration/resource"
-	"github.com/snyk/driftctl/enumeration/resource/aws"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
 )
 
-func initAwsDbInstanceMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
-	resourceSchemaRepository.SetNormalizeFunc(aws.AwsDbInstanceResourceType, func(res *resource.Resource) {
+const AwsDbInstanceResourceType = "aws_db_instance"
+
+func initAwsDbInstanceMetaData(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
+	resourceSchemaRepository.SetNormalizeFunc(AwsDbInstanceResourceType, func(res *resource.Resource) {
 		val := res.Attrs
 		val.SafeDelete([]string{"delete_automated_backups"})
 		val.SafeDelete([]string{"final_snapshot_identifier"})
@@ -19,4 +21,5 @@ func initAwsDbInstanceMetaData(resourceSchemaRepository resource.SchemaRepositor
 		val.SafeDelete([]string{"apply_immediately"})
 		val.DeleteIfDefault("CharacterSetName")
 	})
+	resourceSchemaRepository.SetFlags(AwsDbInstanceResourceType, resource.FlagDeepMode)
 }
