@@ -1,10 +1,13 @@
 package aws
 
-import "github.com/snyk/driftctl/pkg/resource"
+import (
+	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
+)
 
 const AwsRouteTableResourceType = "aws_route_table"
 
-func initAwsRouteTableMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+func initAwsRouteTableMetaData(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
 	resourceSchemaRepository.SetFlags(AwsRouteTableResourceType, resource.FlagDeepMode)
 	resourceSchemaRepository.SetNormalizeFunc(AwsRouteTableResourceType, func(res *resource.Resource) {
 		val := res.Attrs
