@@ -4,17 +4,12 @@ import (
 	"testing"
 	"time"
 
-	"github.com/sirupsen/logrus"
-
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/sqs"
+	"github.com/r3labs/diff/v2"
 	awsresources "github.com/snyk/driftctl/enumeration/resource/aws"
 	"github.com/snyk/driftctl/pkg/analyser"
 	"github.com/snyk/driftctl/test"
-
-	"github.com/r3labs/diff/v2"
-
-	"github.com/aws/aws-sdk-go/aws"
-
-	"github.com/aws/aws-sdk-go/service/sqs"
 	"github.com/snyk/driftctl/test/acceptance"
 	"github.com/snyk/driftctl/test/acceptance/awsutils"
 )
@@ -30,22 +25,7 @@ func TestAcc_Aws_SQSQueue(t *testing.T) {
 				Env: map[string]string{
 					"AWS_REGION": "us-east-1",
 				},
-				PreExec: func() {
-					err := acceptance.RetryFor(60*time.Second, func(doneCh chan struct{}) error {
-						return sqs.New(awsutils.Session()).ListQueuesPages(&sqs.ListQueuesInput{},
-							func(resp *sqs.ListQueuesOutput, lastPage bool) bool {
-								logrus.Debugf("Retrieved %d SQS queues", len(resp.QueueUrls))
-								if len(resp.QueueUrls) >= 2 {
-									doneCh <- struct{}{}
-								}
-								return !lastPage
-							},
-						)
-					})
-					if err != nil {
-						t.Fatal("Timeout while fetching SQS queues")
-					}
-				},
+				ShouldRetry: acceptance.LinearBackoff(10 * time.Minute),
 				Check: func(result *test.ScanResult, stdout string, err error) {
 					if err != nil {
 						t.Fatal(err)
