@@ -3,20 +3,21 @@ package resource
 import (
 	"encoding/json"
 
+	"github.com/snyk/driftctl/enumeration/resource"
 	"github.com/zclconf/go-cty/cty"
 	ctyjson "github.com/zclconf/go-cty/cty/json"
 )
 
 type Deserializer struct {
-	factory ResourceFactory
+	factory resource.ResourceFactory
 }
 
-func NewDeserializer(factory ResourceFactory) *Deserializer {
+func NewDeserializer(factory resource.ResourceFactory) *Deserializer {
 	return &Deserializer{factory}
 }
 
-func (s *Deserializer) Deserialize(ty string, rawList []cty.Value) ([]*Resource, error) {
-	resources := make([]*Resource, 0)
+func (s *Deserializer) Deserialize(ty string, rawList []cty.Value) ([]*resource.Resource, error) {
+	resources := make([]*resource.Resource, 0)
 	for _, rawResource := range rawList {
 		rawResource := rawResource
 		res, err := s.DeserializeOne(ty, rawResource)
@@ -28,7 +29,7 @@ func (s *Deserializer) Deserialize(ty string, rawList []cty.Value) ([]*Resource,
 	return resources, nil
 }
 
-func (s *Deserializer) DeserializeOne(ty string, value cty.Value) (*Resource, error) {
+func (s *Deserializer) DeserializeOne(ty string, value cty.Value) (*resource.Resource, error) {
 	if value.IsNull() {
 		return nil, nil
 	}
@@ -37,7 +38,7 @@ func (s *Deserializer) DeserializeOne(ty string, value cty.Value) (*Resource, er
 	// For example, this ensures we can deserialize sensitive values too.
 	unmarkedVal, _ := value.UnmarkDeep()
 
-	var attrs Attributes
+	var attrs resource.Attributes
 	bytes, _ := ctyjson.Marshal(unmarkedVal, unmarkedVal.Type())
 	err := json.Unmarshal(bytes, &attrs)
 	if err != nil {
