@@ -42,11 +42,6 @@ type AccCheck struct {
 	Check       func(result *test.ScanResult, stdout string, err error)
 }
 
-type RetryConfig struct {
-	Attempts uint8
-	Delay    time.Duration
-}
-
 type AccTestCase struct {
 	DoNotRunTerraform          bool
 	TerraformVersion           string
@@ -60,7 +55,6 @@ type AccTestCase struct {
 	originalEnv                []string
 	tf                         map[string]*tfexec.Terraform
 	ShouldRefreshBeforeDestroy bool
-	RetryDestroy               RetryConfig
 }
 
 func (c *AccTestCase) initTerraformExecutor() error {
@@ -214,11 +208,7 @@ func (c *AccTestCase) terraformApply() error {
 }
 
 func (c *AccTestCase) terraformDestroy() error {
-	if c.RetryDestroy.Attempts == 0 {
-		return c.doDestroy()
-	}
-	r := retrier.New(retrier.ConstantBackoff(int(c.RetryDestroy.Attempts), c.RetryDestroy.Delay), nil)
-
+	r := retrier.New(retrier.ExponentialBackoff(10, time.Second*5), nil)
 	return r.Run(c.doDestroy)
 
 }
