@@ -1,17 +1,17 @@
 package test
 
 import (
-	"io/ioutil"
+	"os"
 	"path"
 	"runtime"
 )
 
 func WriteTestFile(p string, content []byte) error {
 	_, filename, _, _ := runtime.Caller(1)
-	return ioutil.WriteFile(path.Join(path.Dir(filename), p), content, 0644)
+	return os.WriteFile(path.Join(path.Dir(filename), p), content, 0644)
 }
 
 func ReadTestFile(p string) ([]byte, error) {
 	_, filename, _, _ := runtime.Caller(1)
-	return ioutil.ReadFile(path.Join(path.Dir(filename), p))
+	return os.ReadFile(path.Join(path.Dir(filename), p))
 }
